@@ -6,14 +6,13 @@ import (
 	"fmt"
 	"time"
 
-	"github.com/aliyun/alibaba-cloud-sdk-go/sdk"
-	"github.com/aliyun/alibaba-cloud-sdk-go/sdk/auth"
-	"github.com/aliyun/alibaba-cloud-sdk-go/sdk/auth/credentials"
-	"github.com/aliyun/alibaba-cloud-sdk-go/sdk/requests"
-	"github.com/aliyun/alibaba-cloud-sdk-go/services/alidns"
+	alidns "github.com/alibabacloud-go/alidns-20150109/v4/client"
+	openapi "github.com/alibabacloud-go/darabonba-openapi/v2/client"
+	"github.com/aliyun/credentials-go/credentials"
 	"github.com/go-acme/lego/v4/challenge"
 	"github.com/go-acme/lego/v4/challenge/dns01"
 	"github.com/go-acme/lego/v4/platform/config/env"
+	"github.com/go-acme/lego/v4/providers/dns/internal/ptr"
 	"golang.org/x/net/idna"
 )
 
@@ -102,23 +101,42 @@ func NewDNSProviderConfig(config *Config) (*DNSProvider, error) {
 		config.RegionID = defaultRegionID
 	}
 
-	var credential auth.Credential
+	cfg := new(openapi.Config).
+		SetRegionId(config.RegionID).
+		SetReadTimeout(int(config.HTTPTimeout.Milliseconds()))
+
 	switch {
 	case config.RAMRole != "":
-		credential = credentials.NewEcsRamRoleCredential(config.RAMRole)
+		// https://www.alibabacloud.com/help/en/ecs/user-guide/attach-an-instance-ram-role-to-an-ecs-instance
+		credentialsCfg := new(credentials.Config).
+			SetType("ecs_ram_role").
+			SetRoleName(config.RAMRole)
+
+		credentialClient, err := credentials.NewCredential(credentialsCfg)
+		if err != nil {
+			return nil, fmt.Errorf("alicloud: new credential: %w", err)
+		}
+
+		cfg = cfg.SetCredential(credentialClient)
+
 	case config.APIKey != "" && config.SecretKey != "" && config.SecurityToken != "":
-		credential = credentials.NewStsTokenCredential(config.APIKey, config.SecretKey, config.SecurityToken)
+		cfg = cfg.
+			SetAccessKeyId(config.APIKey).
+			SetAccessKeySecret(config.SecretKey).
+			SetSecurityToken(config.SecurityToken)
+
 	case config.APIKey != "" && config.SecretKey != "":
-		credential = credentials.NewAccessKeyCredential(config.APIKey, config.SecretKey)
+		cfg = cfg.
+			SetAccessKeyId(config.APIKey).
+			SetAccessKeySecret(config.SecretKey)
+
 	default:
 		return nil, errors.New("alicloud: ram role or credentials missing")
 	}
 
-	conf := sdk.NewConfig().WithTimeout(config.HTTPTimeout)
-
-	client, err := alidns.NewClientWithOptions(config.RegionID, conf, credential)
+	client, err := alidns.NewClient(cfg)
 	if err != nil {
-		return nil, fmt.Errorf("alicloud: credentials failed: %w", err)
+		return nil, fmt.Errorf("alicloud: new client: %w", err)
 	}
 
 	return &DNSProvider{config: config, client: client}, nil
@@ -139,12 +157,12 @@ func (d *DNSProvider) Present(domain, token, keyAuth string) error {
 		return fmt.Errorf("alicloud: %w", err)
 	}
 
-	recordAttributes, err := d.newTxtRecord(zoneName, info.EffectiveFQDN, info.Value)
+	recordRequest, err := d.newTxtRecord(zoneName, info.EffectiveFQDN, info.Value)
 	if err != nil {
 		return err
 	}
 
-	_, err = d.client.AddDomainRecord(recordAttributes)
+	_, err = d.client.AddDomainRecord(recordRequest)
 	if err != nil {
 		return fmt.Errorf("alicloud: API call failed: %w", err)
 	}
@@ -166,8 +184,10 @@ func (d *DNSProvider) CleanUp(domain, token, keyAuth string) error {
 	}
 
 	for _, rec := range records {
-		request := alidns.CreateDeleteDomainRecordRequest()
-		request.RecordId = rec.RecordId
+		request := &alidns.DeleteDomainRecordRequest{
+			RecordId: rec.RecordId,
+		}
+
 		_, err = d.client.DeleteDomainRecord(request)
 		if err != nil {
 			return fmt.Errorf("alicloud: %w", err)
@@ -177,22 +197,23 @@ func (d *DNSProvider) CleanUp(domain, token, keyAuth string) error {
 }
 
 func (d *DNSProvider) getHostedZone(domain string) (string, error) {
-	request := alidns.CreateDescribeDomainsRequest()
+	request := new(alidns.DescribeDomainsRequest)
 
-	var domains []alidns.DomainInDescribeDomains
-	startPage := 1
+	var domains []*alidns.DescribeDomainsResponseBodyDomainsDomain
+
+	var startPage int64 = 1
 
 	for {
-		request.PageNumber = requests.NewInteger(startPage)
+		request.SetPageNumber(startPage)
 
 		response, err := d.client.DescribeDomains(request)
 		if err != nil {
 			return "", fmt.Errorf("API call failed: %w", err)
 		}
 
-		domains = append(domains, response.Domains.Domain...)
+		domains = append(domains, response.Body.Domains.Domain...)
 
-		if response.PageNumber*response.PageSize >= response.TotalCount {
+		if ptr.Deref(response.Body.PageNumber)*ptr.Deref(response.Body.PageSize) >= ptr.Deref(response.Body.TotalCount) {
 			break
 		}
 
@@ -204,48 +225,45 @@ func (d *DNSProvider) getHostedZone(domain string) (string, error) {
 		return "", fmt.Errorf("could not find zone: %w", err)
 	}
 
-	var hostedZone alidns.DomainInDescribeDomains
+	var hostedZone *alidns.DescribeDomainsResponseBodyDomainsDomain
 	for _, zone := range domains {
-		if zone.DomainName == dns01.UnFqdn(authZone) || zone.PunyCode == dns01.UnFqdn(authZone) {
+		if ptr.Deref(zone.DomainName) == dns01.UnFqdn(authZone) || ptr.Deref(zone.PunyCode) == dns01.UnFqdn(authZone) {
 			hostedZone = zone
 		}
 	}
 
-	if hostedZone.DomainId == "" {
+	if hostedZone == nil || ptr.Deref(hostedZone.DomainId) == "" {
 		return "", fmt.Errorf("zone %s not found in AliDNS for domain %s", authZone, domain)
 	}
 
-	return hostedZone.DomainName, nil
+	return ptr.Deref(hostedZone.DomainName), nil
 }
 
 func (d *DNSProvider) newTxtRecord(zone, fqdn, value string) (*alidns.AddDomainRecordRequest, error) {
-	request := alidns.CreateAddDomainRecordRequest()
-	request.Type = "TXT"
-	request.DomainName = zone
-
-	var err error
-	request.RR, err = extractRecordName(fqdn, zone)
+	rr, err := extractRecordName(fqdn, zone)
 	if err != nil {
 		return nil, err
 	}
 
-	request.Value = value
-	request.TTL = requests.NewInteger(d.config.TTL)
-
-	return request, nil
+	return new(alidns.AddDomainRecordRequest).
+		SetType("TXT").
+		SetDomainName(zone).
+		SetRR(rr).
+		SetValue(value).
+		SetTTL(int64(d.config.TTL)), nil
 }
 
-func (d *DNSProvider) findTxtRecords(fqdn string) ([]alidns.Record, error) {
+func (d *DNSProvider) findTxtRecords(fqdn string) ([]*alidns.DescribeDomainRecordsResponseBodyDomainRecordsRecord, error) {
 	zoneName, err := d.getHostedZone(fqdn)
 	if err != nil {
 		return nil, err
 	}
 
-	request := alidns.CreateDescribeDomainRecordsRequest()
-	request.DomainName = zoneName
-	request.PageSize = requests.NewInteger(500)
+	request := new(alidns.DescribeDomainRecordsRequest).
+		SetDomainName(zoneName).
+		SetPageSize(500)
 
-	var records []alidns.Record
+	var records []*alidns.DescribeDomainRecordsResponseBodyDomainRecordsRecord
 
 	result, err := d.client.DescribeDomainRecords(request)
 	if err != nil {
@@ -257,8 +275,8 @@ func (d *DNSProvider) findTxtRecords(fqdn string) ([]alidns.Record, error) {
 		return nil, err
 	}
 
-	for _, record := range result.DomainRecords.Record {
-		if record.RR == recordName && record.Type == "TXT" {
+	for _, record := range result.Body.DomainRecords.Record {
+		if ptr.Deref(record.RR) == recordName && ptr.Deref(record.Type) == "TXT" {
 			records = append(records, record)
 		}
 	}
