@@ -7,16 +7,11 @@ import (
 	"time"
 
 	"github.com/civo/civogo"
+	"github.com/go-acme/lego/v4/challenge"
 	"github.com/go-acme/lego/v4/challenge/dns01"
 	"github.com/go-acme/lego/v4/platform/config/env"
 )
 
-const (
-	minTTL                    = 600
-	defaultPollingInterval    = 30 * time.Second
-	defaultPropagationTimeout = 300 * time.Second
-)
-
 // Environment variables names.
 const (
 	envNamespace = "CIVO_"
@@ -28,6 +23,14 @@ const (
 	EnvPollingInterval    = envNamespace + "POLLING_INTERVAL"
 )
 
+const (
+	minTTL                    = 600
+	defaultPollingInterval    = 30 * time.Second
+	defaultPropagationTimeout = 300 * time.Second
+)
+
+var _ challenge.ProviderTimeout = (*DNSProvider)(nil)
+
 // Config is used to configure the creation of the DNSProvider.
 type Config struct {
 	ProjectID          string
