@@ -28,6 +28,8 @@ const (
 	EnvHTTPTimeout        = envNamespace + "HTTP_TIMEOUT"
 )
 
+const txtType = "TXT"
+
 var _ challenge.ProviderTimeout = (*DNSProvider)(nil)
 
 // Config is used to configure the creation of the DNSProvider.
@@ -128,7 +130,7 @@ func (d *DNSProvider) Present(domain, token, keyAuth string) error {
 	}
 
 	record := internal.Record{
-		Type:  "TXT",
+		Type:  txtType,
 		Name:  subDomain,
 		Value: info.Value,
 		TTL:   d.config.TTL,
@@ -137,7 +139,7 @@ func (d *DNSProvider) Present(domain, token, keyAuth string) error {
 	// mijn.host doesn't support multiple values for a domain,
 	// so we removed existing record for the subdomain.
 	cleanedRecords := filterRecords(records, func(record internal.Record) bool {
-		return record.Name == subDomain || record.Name == dns01.UnFqdn(info.EffectiveFQDN)
+		return record.Type == txtType && (record.Name == subDomain || record.Name == dns01.UnFqdn(info.EffectiveFQDN))
 	})
 
 	cleanedRecords = append(cleanedRecords, record)
@@ -170,7 +172,7 @@ func (d *DNSProvider) CleanUp(domain, token, keyAuth string) error {
 	}
 
 	cleanedRecords := filterRecords(records, func(record internal.Record) bool {
-		return record.Value == info.Value
+		return record.Type == txtType && record.Value == info.Value
 	})
 
 	err = d.client.UpdateRecords(context.Background(), dom.Domain, cleanedRecords)
