@@ -144,7 +144,6 @@ func TestClient_joinPath(t *testing.T) {
 	}
 
 	for _, test := range testCases {
-		test := test
 		t.Run(test.desc, func(t *testing.T) {
 			t.Parallel()
 
@@ -257,6 +256,7 @@ func TestClient_GetHostedZone_v0(t *testing.T) {
 func TestClient_UpdateRecords(t *testing.T) {
 	client := setupTest(t, http.MethodPatch, "/api/v1/servers/localhost/zones/example.org.", http.StatusOK, "zone.json")
 	client.apiVersion = 1
+	client.serverName = "localhost"
 
 	zone := &HostedZone{
 		ID:   "example.org.",
@@ -283,9 +283,41 @@ func TestClient_UpdateRecords(t *testing.T) {
 	require.NoError(t, err)
 }
 
+func TestClient_UpdateRecords_NonRootApi(t *testing.T) {
+	client := setupTest(t, http.MethodPatch, "/some/path/api/v1/servers/localhost/zones/example.org.", http.StatusOK, "zone.json")
+	client.Host = client.Host.JoinPath("some", "path")
+	client.apiVersion = 1
+	client.serverName = "localhost"
+
+	zone := &HostedZone{
+		ID:   "example.org.",
+		Name: "example.org.",
+		URL:  "some/path/api/v1/servers/server/zones/example.org.",
+		Kind: "Master",
+	}
+
+	rrSets := RRSets{
+		RRSets: []RRSet{{
+			Name:       "example.org.",
+			Type:       "NS",
+			ChangeType: "REPLACE",
+			Records: []Record{{
+				Content: "192.0.2.5",
+				Name:    "ns1.example.org.",
+				TTL:     86400,
+				Type:    "A",
+			}},
+		}},
+	}
+
+	err := client.UpdateRecords(context.Background(), zone, rrSets)
+	require.NoError(t, err)
+}
+
 func TestClient_UpdateRecords_v0(t *testing.T) {
 	client := setupTest(t, http.MethodPatch, "/servers/localhost/zones/example.org.", http.StatusOK, "zone.json")
 	client.apiVersion = 0
+	client.serverName = "localhost"
 
 	zone := &HostedZone{
 		ID:   "example.org.",
@@ -315,6 +347,7 @@ func TestClient_UpdateRecords_v0(t *testing.T) {
 func TestClient_Notify(t *testing.T) {
 	client := setupTest(t, http.MethodPut, "/api/v1/servers/localhost/zones/example.org./notify", http.StatusOK, "")
 	client.apiVersion = 1
+	client.serverName = "localhost"
 
 	zone := &HostedZone{
 		ID:   "example.org.",
@@ -327,8 +360,26 @@ func TestClient_Notify(t *testing.T) {
 	require.NoError(t, err)
 }
 
+func TestClient_Notify_NonRootApi(t *testing.T) {
+	client := setupTest(t, http.MethodPut, "/some/path/api/v1/servers/localhost/zones/example.org./notify", http.StatusOK, "")
+	client.Host = client.Host.JoinPath("some", "path")
+	client.apiVersion = 1
+	client.serverName = "localhost"
+
+	zone := &HostedZone{
+		ID:   "example.org.",
+		Name: "example.org.",
+		URL:  "/some/path/api/v1/servers/server/zones/example.org.",
+		Kind: "Master",
+	}
+
+	err := client.Notify(context.Background(), zone)
+	require.NoError(t, err)
+}
+
 func TestClient_Notify_v0(t *testing.T) {
 	client := setupTest(t, http.MethodPut, "/api/v1/servers/localhost/zones/example.org./notify", http.StatusOK, "")
+	client.apiVersion = 0
 
 	zone := &HostedZone{
 		ID:   "example.org.",
